@@ -15,6 +15,7 @@ else:
 
 if sys.version_info[0] == 2:
     unittest.TestCase.assertRaisesRegex = unittest.TestCase.assertRaisesRegexp
+    unittest.TestCase.assertRegex = unittest.TestCase.assertRegexpMatches
 
 
 class TestReader(unittest.TestCase):
@@ -70,6 +71,20 @@ class TestReader(unittest.TestCase):
             reader.city('invalid')
         reader.close()
 
+    def test_anonymous_ip(self):
+        reader = geoip2.database.Reader(
+            'tests/data/test-data/GeoIP2-Anonymous-IP-Test.mmdb')
+        ip_address = '1.2.0.1'
+
+        record = reader.anonymous_ip(ip_address)
+        self.assertEqual(record.is_anonymous, True)
+        self.assertEqual(record.is_anonymous_vpn, True)
+        self.assertEqual(record.is_hosting_provider, False)
+        self.assertEqual(record.is_public_proxy, False)
+        self.assertEqual(record.is_tor_exit_node, False)
+        self.assertEqual(record.ip_address, ip_address)
+        reader.close()
+
     def test_connection_type(self):
         reader = geoip2.database.Reader(
             'tests/data/test-data/GeoIP2-Connection-Type-Test.mmdb')
@@ -78,6 +93,14 @@ class TestReader(unittest.TestCase):
         record = reader.connection_type(ip_address)
         self.assertEqual(record.connection_type, 'Cable/DSL')
         self.assertEqual(record.ip_address, ip_address)
+
+        self.assertRegex(
+            str(record), r'ConnectionType\(\{.*Cable/DSL.*\}\)',
+            'ConnectionType str representation is reasonable')
+
+        self.assertEqual(record, eval(repr(record)),
+                         "ConnectionType repr can be eval'd")
+
         reader.close()
 
     def test_domain(self):
@@ -89,6 +112,13 @@ class TestReader(unittest.TestCase):
         self.assertEqual(record.domain, 'maxmind.com')
         self.assertEqual(record.ip_address, ip_address)
 
+        self.assertRegex(
+            str(record), r'Domain\(\{.*maxmind.com.*\}\)',
+            'Domain str representation is reasonable')
+
+        self.assertEqual(record, eval(repr(record)),
+                         "Domain repr can be eval'd")
+
         reader.close()
 
     def test_isp(self):
@@ -104,4 +134,11 @@ class TestReader(unittest.TestCase):
         self.assertEqual(record.organization, 'Telstra Internet')
         self.assertEqual(record.ip_address, ip_address)
 
+        self.assertRegex(
+            str(record), r'ISP\(\{.*Telstra.*\}\)',
+            'ISP str representation is reasonable')
+
+        self.assertEqual(record, eval(repr(record)),
+                         "ISP repr can be eval'd")
+
         reader.close()
