@@ -253,25 +253,15 @@ class TestClient(unittest.TestCase):
         self.assertEqual(type(city), geoip2.models.City,
                          'return value of client.city')
 
-    def test_city_isp_org_ok(self):
-        httpretty.register_uri(httpretty.GET,
-                               self.base_uri + 'city/1.2.3.4',
-                               body=json.dumps(self.country),
-                               status=200,
-                               content_type=self._content_type('country'))
-        city_isp_org = self.client.city_isp_org('1.2.3.4')
-        self.assertEqual(type(city_isp_org), geoip2.models.City,
-                         'return value of client.city_isp_org')
-
     def test_insights_ok(self):
         httpretty.register_uri(httpretty.GET,
                                self.base_uri + 'insights/1.2.3.4',
                                body=json.dumps(self.country),
                                status=200,
                                content_type=self._content_type('country'))
-        omni = self.client.insights('1.2.3.4')
-        self.assertEqual(type(omni), geoip2.models.Insights,
-                         'return value of client.omni')
+        insights = self.client.insights('1.2.3.4')
+        self.assertEqual(type(insights), geoip2.models.Insights,
+                         'return value of client.insights')
 
     def test_insights_ok(self):
         httpretty.register_uri(httpretty.GET,
